%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Title: execmain
%  Author: CGN
%    Date: 10/17/16
% Purpose: produces calibration figure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [] = execmain()

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % parameters
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
        % INPUTS 
    
            % construction cost (irrelevant)
            k = 1;

            % demand elasticity
            eps = 1;

            % demand shock
            x = 0.5;

            % mean belief (mu bar)
            mub = 0.2;

            % disagreement scale parameter
            z = 1;

            % optimism share
            opt = 0.1;
            assert(opt>0&&opt<1);
            
            % land demand elasticity
            epsl = 1;
            
            % land demand at k
            Nl=0.01;

        % DERIVED
        
            % theta values
            theta = [1;-opt/(1-opt)];
            
            % belief distribution
            f = [opt;1-opt];
       
            % demand function
            D = @(v) (k./(k+(v-k).*(v>k))).^eps;
            
            % house price at t=1 in bsaeline
            p1h = @(N1) k.*(1+(N1-1).*(N1>1)).^(1/eps);
            
            % land demand
            Dl = @(r) Nl*(k./r).^epsl;
            Dlprime = @(r)-epsl*Nl*k^epsl*r.^(-epsl-1);
            
            % supply elasticity
            epss = @(p1h)-p1h.*Dlprime(p1h-k)./(1-Dl(p1h-k));
            
        % SAVE
        
            % seed
            params = [];
            
            % store
            params.k=k;
            params.eps=eps;
            params.x=x;
            params.mub=mub;
            params.z=z;
            params.opt=0.1;
            params.theta=theta;
            params.f=f;
            params.D=D;
            params.p1h=p1h;
            params.Dl=Dl;
            params.Dlprime=Dlprime;
            
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % baseline prices
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
        % N0star
        N0star = getN0star(x,z,params);
        xmax=2*N0star;
    
        % values of N0 from 0 to 2*N0star
        N0 = linspace(0,xmax,1000);
        
        % prices with shock and disagreement
        p0h = getp0h(N0,x,z,params);
        
        % prices without shock
        p0hx0 = getp0h(N0,0,z,params);
        
        % prices without disagreement
        p0hz0 = getp0h(N0,x,0,params);
        
        % booms
        boom_agree    = p0hz0./p0hx0-1;
        boom_disagree = p0h./p0hx0-1;
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % generate baseline output
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        % draw figure 
        plot(N0,boom_disagree,'-',N0,boom_agree,'--');
        legend('With Disagreement','Without Disagreement'); 
        set(gca,'XTick',[0,1,N0star]);
        set(gca,'TickLabelInterpreter','latex');
        set(gca,'XTickLabel',{'0','1','$N_0^*(x,z)$'});
        xlim([0,xmax]);
        yl=ylim;
        ylim([-0*yl(2),yl(2)]);
        set(gca,'YTick',[0,yl(2)]);
        xlabel('$N_0$','interpreter','latex');
        ylabel('Boom Size');
        set(gca,'box','off');
        set(gca,'XAxisLocation','origin');
        
        % save figure
        saveas(gcf,'../output/figure_2','epsc');
        saveas(gcf,'../output/figure_2','pdf');
        saveas(gcf,'../output/figure_2_bw','eps');
        close(gcf);
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % boom in extension
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
        % update parameters
        x=1;
        mub=1;
        N0=linspace(0,3,1000);
        
        % p1h
        p1h_ext_0=getp1h(N0,params);
        p1h_ext_1=getp1h(exp(mub*x)*N0,params);
        
        % pass-through fraction
        ptf = p1h_ext_1./(p1h_ext_0+p1h_ext_1);
        
        % total pass-through
        epss_1 = epss(p1h_ext_1);
        pt = ptf./(epss_1+eps);
       
        % belief with agreement
        mu_agree = mub;
        
        % belief with disagreement
        mumax=mub+z*max(theta);
        epss_0 = epss(p1h_ext_0);
        mu_disagree = (epss_0*mumax+eps*mub)./(epss_0+eps);
        
        % total boom
        boom_agree = mu_agree*pt;
        boom_disagree = mu_disagree.*pt;
        
        % elasticity quantities for plots
        eps_plot_0 = 1./(epss_0+eps);
        eps_plot_1 = 1./(epss_1+eps);
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % generate extension output
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
        % elasticity plot
        plot(N0,eps_plot_0,'-',N0,eps_plot_1,'--');
        h=legend('$t=0$','$t=1$');
        set(h,'Interpreter','latex');
        set(gca,'XTick',[0,1]);
        set(gca,'XTickLabel',{'0','1'});
        yl=ylim;
        set(gca,'YTick',[0,yl(2)]);
        xlabel('$N_0$','interpreter','latex');
        ylabel('$(\epsilon^s_t+\epsilon)^{-1}$','interpreter','latex');
        set(gca,'box','off');
        set(gca,'XAxisLocation','origin');
        
        % save
        saveas(gcf,'../output/figure_IA1_A','epsc');
        saveas(gcf,'../output/figure_IA1_A','pdf');
        close(gcf);
        
        % boom plot
        plot(N0,boom_disagree,'-',N0,boom_agree,'--');
        legend('With Disagreement','Without Disagreement'); 
        set(gca,'XTick',[0,1]);
        set(gca,'XTickLabel',{'0','1'});
        yl=ylim;
        set(gca,'YTick',[0,yl(2)]);
        xlabel('$N_0$','interpreter','latex');
        ylabel('Pass-Through of $x$ to $\log p_0^h$',...
            'interpreter','latex');
        set(gca,'box','off');
        set(gca,'XAxisLocation','origin');
        
        % save
        saveas(gcf,'../output/figure_IA1_B','epsc');
        saveas(gcf,'../output/figure_IA1_B','pdf');
        close(gcf);
        
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
end