*******************************************************************************
*   Title: replicate_stata_figures_partII.do
* Purpose: Produce figures and tables for final published version. Includes:
*          
*    * Panel C of Figure 4 
*    * Figure 6
*    * Table IAI
*
*   Owner: Eric Zwick
*    Date: 2018-05-31
*******************************************************************************

set scheme tufte
global elas_demand = .6

* Helper for pub ready graphs./*%<*/
capture program drop graph_export
program define graph_export

    graph export "`1'.pdf", replace
    graph export "`1'.eps", replace

end/*%>*/

*******************************************************************************
* Cross-city analysis
*******************************************************************************
capture program drop load_crosscity/*%<*/
program define load_crosscity

    use $analysis/crosscity.dta, clear

    gen log_pop = log(population)
    gen log_income = log(medianHHI)
    local demographics log_pop log_income white whitenothisp lessthan9 lessthan12 ///
        unemployed poorfamilies
    describe `demographics', fullname
    gen scaled_boom = (elasticity + $elas_demand) * boom0006_fixed
    reg scaled_boom `demographics'
    predict scaled_boom_predicted, xb
    gen boom_predicted = scaled_boom_predicted/(elasticity + $elas_demand)

    foreach x of varlist boom0006_fixed growth0006 boom_predicted {
        replace `x' = 100*`x'
    }

end/*%>*/

capture program drop graph_predicted/*%<*/
program define graph_predicted

    tempfile orig
    save `orig'
    
    * 3. Residual plot.
    #delimit;
    twoway (scatter boom0006_fixed boom_predicted if inelastic != 1 & anomaly != 1,
            mcolor(gs10) msymbol(+))
           (scatter boom0006_fixed boom_predicted if inelastic == 1,
            mcolor(maroon) msymbol(Dh))
           (scatter boom0006_fixed boom_predicted if anomaly == 1,
            mcolor(edkblue) msymbol(O)) 
           (lfit boom_predicted boom_predicted, 
            lpattern(shortdash) lcolor(gray*0.8)),
           xtitle("Predicted Price Growth (%)")
           ytitle("Actual Price Growth (%)")
           yscale(range(15))
           plotregion(lcolor(black))
           ylabel(, nogrid)
           legend(order(3 "Anomalous Cities" 2 "Inelastic Cities" 4 "45-Degree Line") ring(0)
                  bplacement(nwest) region(lstyle(solid) lcolor(black)))
    ;
    #delimit cr
    graph_export "figure_6"

    #delimit;
    twoway (scatter boom0006_fixed boom_predicted if inelastic != 1 & anomaly != 1,
            mcolor(gray*0.8) msymbol(+))
           (scatter boom0006_fixed boom_predicted if inelastic == 1,
            mcolor(gray*1.5) msymbol(Dh))
           (scatter boom0006_fixed boom_predicted if anomaly == 1,
            mcolor(gray*1.9) msymbol(O)) 
           (lfit boom_predicted boom_predicted, 
            lpattern(shortdash) lcolor(gray*0.8)),
           xtitle("Predicted Price Growth (%)")
           ytitle("Actual Price Growth (%)")
           yscale(range(15))
           plotregion(lcolor(black))
           ylabel(, nogrid)
           legend(order(3 "Anomalous Cities" 2 "Inelastic Cities" 4 "45-Degree Line") ring(0)
                  bplacement(nwest) region(lstyle(solid) lcolor(black)))
    ;
    #delimit cr
    graph_export "figure_6_bw"

    use `orig', clear

end/*%>*/

capture program drop table_predicted/*%<*/
program define table_predicted

    tempfile orig
    save `orig'

    * 5. Regression version.
    local demographics log_pop log_income white whitenothisp lessthan9 lessthan12 ///
        unemployed poorfamilies
    gen total_elas = elasticity + $elas_demand
    gen is_anomaly = anomaly == 1
    gen is_anomalyXtotal_elas = is_anomaly * total_elas

    sum scaled_boom total_elas `demographics'

    gen white_share = white/100
    gen whitenothisp_share = whitenothisp/100
    gen lessthan9_share = lessthan9/100
    gen lessthan12_share = lessthan12/100
    gen unemployed_share = unemployed/100
    gen poorfamilies_share = poorfamilies/100
    local demographics_share log_pop log_income white_share whitenothisp_share ///
        lessthan9_share lessthan12_share unemployed_share poorfamilies_share

    eststo: reg scaled_boom is_anomalyXtotal_elas
    eststo: reg scaled_boom is_anomalyXtotal_elas `demographics_share'

    #delimit ;
    esttab using "table_E1.tex",
        label replace se booktabs nonumbers fragment b(a2)
            mgroups("LHS Variable is $(\epsilon_j^s + \epsilon)\times (\Delta \log p_j^h)",
            prefix(\multicolumn{@span}{c}{) suffix(})
                span erepeat(\cmidrule(lr){@span}))
            mtitles("No Demographics" "Including Demographics")
            scalars("N Observations" "r2 R$^2$");
    #delimit cr
    estimates clear

    use `orig', clear

end/*%>*/

*******************************************************************************
* Short interest analysis
*******************************************************************************
capture program drop load_shortinterest/*%<*/
program define load_shortinterest

    use $analysis/shortinterest.dta, clear
    gen count = 1
    collapse (mean) short_ratio (sum) count, by(naics)

end/*%>*/

capture program drop graph_shortinterest/*%<*/
program define graph_shortinterest

    tempfile orig
    save `orig'

    replace short_ratio = 100*short_ratio

    qui sum short_ratio if naics == "236117"
    local builders = `r(mean)'
    qui sum short_ratio if naics == "523110"
    local ibanks = `r(mean)'
    
    * Note: Graph focuses on industries below 12% (17 of 735 industries) to make
    * it easier to see the full distribution. Statistics in the paper do not
    * condition on short_ratio level.
    #delimit;
    distplot short_ratio if short_ratio <= 12, 
        lcolor(blue)
        xtitle("Average Short Ratio (%)") 
        ytitle ("Cumulative Density")
        xsize(8)
        yscale(range(1))
        xscale(range(0 12))
        xlab(0 4 8 12)
        plotregion(lcolor(black))
        ylabel(, nogrid)
        xline(`builders', lc(red) lp(dash))
        xline(`ibanks', lc(black) lp(dash));
    #delimit cr
    graph_export "figure_4c"

    #delimit;
    distplot short_ratio if short_ratio <= 12, 
        lcolor(black)
        xtitle("Average Short Ratio (%)") 
        ytitle ("Cumulative Density")
        xsize(8)
        yscale(range(1))
        xscale(range(0 12))
        xlab(0 4 8 12)
        plotregion(lcolor(black))
        ylabel(, nogrid)
        xline(`builders', lc(gray) lp(dash))
        xline(`ibanks', lc(gray) lp(dash));
    #delimit cr
    graph_export "figure_4c_bw"

    use `orig', clear

end/*%>*/

*******************************************************************************
* Main
*******************************************************************************
capture program drop main
program define main

    * Paths defined relative to code/ dir.
    global outputdir "../output"
    global localcodedir "../code"
    global analysis "../data"

    cd "$outputdir"
    log using "replicate_stata_figures_partII.log", replace

    set trace on
    set tracedepth 1

    load_crosscity
    graph_predicted
    table_predicted

    load_shortinterest
    graph_shortinterest

    cd $localcodedir
    log close
end

main
